@@ -1,6 +1,7 @@
 use super::Exceptions;
 use async_stream::stream;
 use futures_core::stream::Stream;
+use if_chain::if_chain;
 use path_absolutize::*;
 use std::fs;
 use walkdir::WalkDir;
@@ -24,16 +25,20 @@ pub fn file_generator(interpreter: super::super::Interpreter) -> impl Stream<Ite
             ),
         )
     }
-    let generator = stream! {
+    stream! {
         // is it recursive? ok, use the library
         // no? we use our implementation
         if interpreter.__recursive__ {
             for e in WalkDir::new(&interpreter.__directory__)
                 .into_iter()
-                .filter_map(|e| e.ok())
             {
-                if e.metadata().unwrap().is_file() {
-                    yield e.path().display().to_string();
+                if_chain! {
+                    if let Ok(entry) = e;
+                    if let Ok(metadata) = entry.metadata();
+                    if metadata.is_file();
+                    then {
+                        yield entry.path().display().to_string();
+                    } else { continue }
                 }
             }
             return;
@@ -42,11 +47,10 @@ pub fn file_generator(interpreter: super::super::Interpreter) -> impl Stream<Ite
                 let p = entry.unwrap().path();
                 let path = p.absolutize().unwrap();
                 if let Ok(metadata) = fs::metadata(&path) {
-                    yield if metadata.is_file() { path.to_str().unwrap().to_string() } else { continue };
+                    if metadata.is_file() { yield path.to_str().unwrap().to_string() } else { continue };
                 }
             }
             return;
         }
-    };
-    return generator;
+    }
 }
