@@ -32,7 +32,7 @@ pub fn parse(tokens: Vec<super::lexer::Token>) -> AST {
             // conditionals will stop when the condr of the next is null,
             // so then we stop
             match conditional.next_conditional_relationship {
-                CondRelationship::Null => break,
+                None => break,
                 _ => continue,
             }
         }
@@ -75,7 +75,7 @@ impl Parser {
             cycles: vec![],
             raw_cycles: vec![],
             current_cycle_funcs: vec![],
-            current_function: "".to_string(),
+            current_function: None,
             current_function_args: vec![],
             parsing_args: false,
         }
